Revert 84315 for now. Re-thinking the patch.

git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@84321 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/PseudoSourceValue.cpp b/lib/CodeGen/PseudoSourceValue.cpp
index e74479e..00c5d46 100644
--- a/lib/CodeGen/PseudoSourceValue.cpp
+++ b/lib/CodeGen/PseudoSourceValue.cpp
@@ -52,31 +52,29 @@
 }
 
 namespace {
   /// StackObjectPseudoSourceValue - A specialized PseudoSourceValue
   /// for holding StackObject values, which must include a frame
   /// index.
-  class VISIBILITY_HIDDEN StackObjectPseudoSourceValue
+  class VISIBILITY_HIDDEN FixedStackPseudoSourceValue
     : public PseudoSourceValue {
     const int FI;
   public:
-    explicit StackObjectPseudoSourceValue(int fi) : FI(fi) {}
+    explicit FixedStackPseudoSourceValue(int fi) : FI(fi) {}
 
     virtual bool isConstant(const MachineFrameInfo *MFI) const;
 
     virtual void printCustom(raw_ostream &OS) const {
-      if (FI < 0)
-        OS << "Fixed";
-      OS << "StackObject" << FI;
+      OS << "FixedStack" << FI;
     }
   };
 }
 
 static ManagedStatic<std::map<int, const PseudoSourceValue *> > FSValues;
 
-const PseudoSourceValue *PseudoSourceValue::getStackObject(int FI) {
+const PseudoSourceValue *PseudoSourceValue::getFixedStack(int FI) {
   const PseudoSourceValue *&V = (*FSValues)[FI];
   if (!V)
-    V = new StackObjectPseudoSourceValue(FI);
+    V = new FixedStackPseudoSourceValue(FI);
   return V;
 }
 
@@ -91,7 +89,6 @@
   return false;
 }
 
-bool
-StackObjectPseudoSourceValue::isConstant(const MachineFrameInfo *MFI) const {
+bool FixedStackPseudoSourceValue::isConstant(const MachineFrameInfo *MFI) const{
   return MFI && MFI->isImmutableObjectIndex(FI);
 }
@@ -52,31 +52,29 @@
 
 namespace {
-  /// StackObjectPseudoSourceValue - A specialized PseudoSourceValue
-  /// for holding StackObject values, which must include a frame
+  /// FixedStackPseudoSourceValue - A specialized PseudoSourceValue
+  /// for holding FixedStack values, which must include a frame
   /// index.